@@ -33,3 +33,16 @@ class BoundLogger(BoundLoggerBase):
         wrapped = partial(self._proxy_to_logger, method_name)
         setattr(self, method_name, wrapped)
         return wrapped
+
+    def __getstate__(self):
+        """
+        Out __getattr__ magic makes this necessary.
+        """
+        return self.__dict__
+
+    def __setstate__(self, state):
+        """
+        Out __getattr__ magic makes this necessary.
+        """
+        for k, v in state.items():
+            setattr(self, k, v)
