@@ -8,7 +8,7 @@ Helpers that make development with ``structlog`` more pleasant.
 
 from __future__ import absolute_import, division, print_function
 
-from six import StringIO
+from six import PY2, StringIO, string_types
 
 
 try:
@@ -93,6 +93,10 @@ class ConsoleRenderer(object):
     """
     Render `event_dict` nicely aligned, possibly in colors, and ordered.
 
+    If `event_dict` contains an ``exception`` key (for example from
+    :func:`~structlog.processors.format_exc_info`), it will be rendered *after*
+    the log line.
+
     :param int pad_event: Pad the event to this many characters.
     :param bool colors: Use colors for a nicer output.
     :param bool force_colors: Force colors even for non-tty destinations.
@@ -117,16 +121,21 @@ class ConsoleRenderer(object):
     .. versionadded:: 17.1 *repr_native_str*
     .. versionadded:: 18.1 *force_colors*
     .. versionadded:: 18.1 *level_styles*
+    .. versionchanged:: 19.2
+       ``colorama`` now initializes lazily to avoid unwanted initializations as
+       ``ConsoleRenderer`` is used by default.
+    .. versionchanged:: 19.2 Can be pickled now.
     """
 
     def __init__(
         self,
         pad_event=_EVENT_WIDTH,
-        colors=True,
+        colors=_has_colorama,
         force_colors=False,
         repr_native_str=False,
         level_styles=None,
     ):
+        self._force_colors = self._init_colorama = False
         if colors is True:
             if colorama is None:
                 raise SystemError(
@@ -136,11 +145,9 @@ class ConsoleRenderer(object):
                     )
                 )
 
+            self._init_colorama = True
             if force_colors:
-                colorama.deinit()
-                colorama.init(strip=False)
-            else:
-                colorama.init()
+                self._force_colors = True
 
             styles = _ColorfulStyles
         else:
@@ -160,19 +167,31 @@ class ConsoleRenderer(object):
             max(self._level_to_color.keys(), key=lambda e: len(e))
         )
 
-        if repr_native_str is True:
-            self._repr = repr
+        self._repr_native_str = repr_native_str
+
+    def _repr(self, val):
+        """
+        Determine representation of *val* depending on its type &
+        self._repr_native_str.
+        """
+        if self._repr_native_str is True:
+            return repr(val)
+
+        if isinstance(val, str):
+            return val
         else:
-
-            def _repr(inst):
-                if isinstance(inst, str):
-                    return inst
-                else:
-                    return repr(inst)
-
-            self._repr = _repr
+            return repr(val)
 
     def __call__(self, _, __, event_dict):
+        # Initialize lazily to prevent import side-effects.
+        if self._init_colorama:
+            if self._force_colors:
+                colorama.deinit()
+                colorama.init(strip=False)
+            else:
+                colorama.init()
+
+            self._init_colorama = False
         sio = StringIO()
 
         ts = event_dict.pop("timestamp", None)
@@ -194,7 +213,11 @@ class ConsoleRenderer(object):
                 + "] "
             )
 
+        # force event to str for compatibility with standard library
         event = event_dict.pop("event")
+        if not PY2 or not isinstance(event, string_types):
+            event = str(event)
+
         if event_dict:
             event = _pad(event, self._pad_event) + self._styles.reset + " "
         else:
@@ -267,3 +290,23 @@ class ConsoleRenderer(object):
             "debug": styles.level_debug,
             "notset": styles.level_notset,
         }
+
+
+_SENTINEL = object()
+
+
+def set_exc_info(_, method_name, event_dict):
+    """
+    Set ``event_dict["exc_info"] = True`` if *method_name* is ``"exception"``.
+
+    Do nothing if the name is different or ``exc_info`` is already set.
+    """
+    if (
+        method_name != "exception"
+        or event_dict.get("exc_info", _SENTINEL) is not _SENTINEL
+    ):
+        return event_dict
+
+    event_dict["exc_info"] = True
+
+    return event_dict
