@@ -25,7 +25,7 @@ class _FixedFindCallerLogger(logging.Logger):
     Change the behavior of findCaller to cope with structlog's extra frames.
     """
 
-    def findCaller(self, stack_info=False):
+    def findCaller(self, stack_info=False, stacklevel=1):
         """
         Finds the first caller frame outside of structlog so that the caller
         info is populated for wrapping stdlib.
@@ -54,6 +54,9 @@ class BoundLogger(BoundLoggerBase):
             wrapper_class=structlog.stdlib.BoundLogger,
         )
 
+    It also contains a bunch of properties that pass-through to the wrapped
+    :class:`logging.Logger` which should make it work as a drop-in
+    replacement.
     """
 
     def debug(self, event=None, *args, **kw):
@@ -120,9 +123,52 @@ class BoundLogger(BoundLoggerBase):
         )
 
     #
-    # Pass-through methods to mimick the stdlib's logger interface.
+    # Pass-through attributes and methods to mimick the stdlib's logger
+    # interface.
     #
 
+    @property
+    def name(self):
+        """
+        Returns :attr:`logging.Logger.name`
+        """
+        return self._logger.name
+
+    @property
+    def level(self):
+        """
+        Returns :attr:`logging.Logger.level`
+        """
+        return self._logger.level
+
+    @property
+    def parent(self):
+        """
+        Returns :attr:`logging.Logger.parent`
+        """
+        return self._logger.parent
+
+    @property
+    def propagate(self):
+        """
+        Returns :attr:`logging.Logger.propagate`
+        """
+        return self._logger.propagate
+
+    @property
+    def handlers(self):
+        """
+        Returns :attr:`logging.Logger.handlers`
+        """
+        return self._logger.handlers
+
+    @property
+    def disabled(self):
+        """
+        Returns :attr:`logging.Logger.disabled`
+        """
+        return self._logger.disabled
+
     def setLevel(self, level):
         """
         Calls :meth:`logging.Logger.setLevel` with unmodified arguments.
@@ -419,12 +465,19 @@ class ProcessorFormatter(logging.Formatter):
         added to the ``event_dict`` and removed afterwards. Set this to
         ``True`` to keep it on the :class:`logging.LogRecord`. (default: False)
     :param bool keep_stack_info: Same as *keep_exc_info* except for Python 3's
-        ``stack_info``.
-
+        ``stack_info``. (default: False)
+    :param logger: Logger which we want to push through the ``structlog``
+        processor chain. This parameter is necessary for some of the
+        processors like `filter_by_level`. (default: None)
+    :param bool pass_foreign_args: If True, pass a foreign log record's
+        ``args`` attribute to the ``event_dict`` under ``positional_args`` key.
+        (default: False)
     :rtype: str
 
     .. versionadded:: 17.1.0
     .. versionadded:: 17.2.0 *keep_exc_info* and *keep_stack_info*
+    .. versionadded:: 19.2.0 *logger*
+    .. versionadded:: 19.2.0 *pass_foreign_args*
     """
 
     def __init__(
@@ -433,6 +486,8 @@ class ProcessorFormatter(logging.Formatter):
         foreign_pre_chain=None,
         keep_exc_info=False,
         keep_stack_info=False,
+        logger=None,
+        pass_foreign_args=False,
         *args,
         **kwargs
     ):
@@ -443,6 +498,8 @@ class ProcessorFormatter(logging.Formatter):
         self.keep_exc_info = keep_exc_info
         # The and clause saves us checking for PY3 in the formatter.
         self.keep_stack_info = keep_stack_info and PY3
+        self.logger = logger
+        self.pass_foreign_args = pass_foreign_args
 
     def format(self, record):
         """
@@ -453,7 +510,7 @@ class ProcessorFormatter(logging.Formatter):
         record = logging.makeLogRecord(record.__dict__)
         try:
             # Both attached by wrap_for_formatter
-            logger = record._logger
+            logger = self.logger if self.logger is not None else record._logger
             meth_name = record._name
 
             # We need to copy because it's possible that the same record gets
@@ -461,9 +518,13 @@ class ProcessorFormatter(logging.Formatter):
             # would transform our dict into a str.
             ed = record.msg.copy()
         except AttributeError:
-            logger = None
+            logger = self.logger
             meth_name = record.levelname.lower()
             ed = {"event": record.getMessage(), "_record": record}
+
+            if self.pass_foreign_args:
+                ed["positional_args"] = record.args
+
             record.args = ()
 
             # Add stack-related attributes to event_dict and unset them
@@ -483,7 +544,7 @@ class ProcessorFormatter(logging.Formatter):
             # Non-structlog allows to run through a chain to prepare it for the
             # final processor (e.g. adding timestamps and log levels).
             for proc in self.foreign_pre_chain or ():
-                ed = proc(None, meth_name, ed)
+                ed = proc(logger, meth_name, ed)
 
             del ed["_record"]
 
